import re
import porter
import lovins
import psyco



def simpleTokenizer(text, stemmer=lovins.stem, word_filter=None):
    """A quick and dirty tokenizer that splits against any
    non-word/non-quotation character.  We also do some elimination of
    common stop words from the text, and all of the tokens are
    lowercased."""
    if word_filter == None:
        word_filter = isGoodWord
    chunks = [word.lower() for word in re.split("[^\w']+", text)]
    return map(stemmer, filter(word_filter, chunks))


def isGoodWord(x):
    return x and not isStopWord(x)


def isStopWord(word):
    """Returns true if the given word is a "stop word", a common word
    in English that doesn't contribute much to the meaning of a
    sentence.

    The words below were empircially gathered; there's a good stop list
    at NCBI here:

         [add url here]
    """
    return word.upper() in STOP_WORDS_DICT

STOP_WORDS = """
NOT
NULL
NONE
AIM
MIN
A
DID
IT
PERHAPS
THESE
ABOUT
DO
ITS
QUITE
THEY
AGAIN
DOES
ITSELF
RATHER
THIS
ALL
DONE
JUST
REALLY
THOSE
ALMOST
DUE
KG
REGARDING
THROUGH
ALSO
DURING
KM
SEEM
THUS
ALTHOUGH
EACH
MADE
SEEN
TO
ALWAYS
EITHER
MAINLY
SEVERAL
UPON
AMONG
ENOUGH
MAKE
SHOULD
USE
AN
ESPECIALLY
MAY
SHOW
USED
AND
ETC
MG
SHOWED
USING
ANOTHER
FOR
MIGHT
SHOWN
VARIOUS
ANY
FOUND
ML
SHOWS
VERY
ARE
FROM
MM
SIGNIFICANTLY
WAS
AS
FURTHER
MOST
SINCE
WE
AT
HAD
MOSTLY
SO
WERE
BE
HAS
MUST
SOME
WHAT
BECAUSE
HAVE
NEARLY
SUCH
WHEN
BEEN
HAVING
NEITHER
THAN
WHICH
BEFORE
HERE
NO
THAT
WHILE
BEING
HOW
NOR
THE
WITH
BETWEEN
HOWEVER
OBTAINED
THEIR
WITHIN
BOTH
I
OF
THEIRS
WITHOUT
BUT
IF
OFTEN
THEM
WOULD
BY
IN
ON
THEN
CAN
INTO
OUR
THERE
COULD
IS
OVERALL
THEREFORE""".split()

## In Python 2.3, we should probably use a Set.  Until then, I'll
## stick with a simple dictionary:
STOP_WORDS_DICT = dict(zip(STOP_WORDS, [1]*len(STOP_WORDS)))




##psyco.bind(porter.stem)
psyco.bind(simpleTokenizer)
psyco.bind(isGoodWord)
psyco.bind(isStopWord)
